#!/usr/bin/env python
# -*- coding: utf-8 -*-

__author__ = "Jason Lewris"
__license__ = "MIT"
__version__ = "0.2.1"
__maintainer__ = "Jason Lewris"
__email__ = "datawrestler@gmail.com"
__status__ = "Beta"

from distutils.core import setup

setup(
    name='afterhours',
    py_modules =['afterhours'],
    version = '0.2.1',
    author='Jason Lewris',
    author_email='datawrestler@gmail.com',
    description='retrieve pre and after hours stock trading information from Nasdaq',
    url='https://github.com/datawrestler/after-hours',
    download_url='https://github.com/datawrestler/after-hours/archive/0.2.1.tar.gz',
    keywords=['stocks', 'stockmarket', 'market', 'finance', 'nasdaq', 'afterhours', 'premarket', 'postmarket'],
    license='The MIT License (MIT)',
    classifiers=[],
)
